import { PublicKey } from '@solana/web3.js';
import { IWallet, ITransport, CreateGameAccountParams, CloseGameAccountParams, JoinParams, DepositParams, VoteParams, CreatePlayerProfileParams, PublishGameParams, CreateRegistrationParams, RegisterGameParams, UnregisterGameParams, GameAccount, GameBundle, PlayerProfile, ServerAccount, RegistrationAccount, IToken, INft, RegistrationWithGames, RecipientAccount, RecipientClaimParams, IStorage, TransactionResult } from '@race-foundation/sdk-core';
import { GameState, RecipientState, RegistryState, ServerState } from './accounts';
export declare class SolanaTransport implements ITransport {
    #private;
    constructor(endpoint: string);
    get chain(): string;
    _fetchLegacyTokens(): Promise<void>;
    createGameAccount(wallet: IWallet, params: CreateGameAccountParams): Promise<TransactionResult<string>>;
    closeGameAccount(wallet: IWallet, params: CloseGameAccountParams): Promise<TransactionResult<void>>;
    join(wallet: IWallet, params: JoinParams): Promise<TransactionResult<void>>;
    deposit(_wallet: IWallet, _params: DepositParams): Promise<TransactionResult<void>>;
    publishGame(_wallet: IWallet, _params: PublishGameParams): Promise<TransactionResult<string>>;
    vote(_wallet: IWallet, _params: VoteParams): Promise<TransactionResult<void>>;
    recipientClaim(_wallet: IWallet, _params: RecipientClaimParams): Promise<TransactionResult<void>>;
    createPlayerProfile(wallet: IWallet, params: CreatePlayerProfileParams): Promise<TransactionResult<void>>;
    createRegistration(wallet: IWallet, params: CreateRegistrationParams): Promise<TransactionResult<string>>;
    registerGame(wallet: IWallet, params: RegisterGameParams): Promise<TransactionResult<void>>;
    unregisterGame(wallet: IWallet, params: UnregisterGameParams): Promise<TransactionResult<void>>;
    getGameAccount(addr: string): Promise<GameAccount | undefined>;
    getGameBundle(addr: string): Promise<GameBundle | undefined>;
    getPlayerProfile(addr: string): Promise<PlayerProfile | undefined>;
    getServerAccount(addr: string): Promise<ServerAccount | undefined>;
    getRegistration(addr: string): Promise<RegistrationAccount | undefined>;
    getRegistrationWithGames(addr: string): Promise<RegistrationWithGames | undefined>;
    getRecipient(addr: String): Promise<RecipientAccount | undefined>;
    _fetchImageFromDataUri(dataUri: string): Promise<string | undefined>;
    getToken(addr: string): Promise<IToken | undefined>;
    /**
     * List popular tokens.
     *
     * [USDT, USDC, SOL, RACE]
     */
    listTokens(storage?: IStorage): Promise<IToken[]>;
    fetchBalances(walletAddr: string, tokenAddrs: string[]): Promise<Map<string, bigint>>;
    getNft(addr: string | PublicKey, storage?: IStorage): Promise<INft | undefined>;
    listNfts(walletAddr: string, storage?: IStorage): Promise<INft[]>;
    _getGameState(gameAccountKey: PublicKey): Promise<GameState | undefined>;
    _getRecipientState(recipientAccountKey: PublicKey): Promise<RecipientState | undefined>;
    _getMultiGameStates(gameAccountKeys: PublicKey[]): Promise<Array<GameState | undefined>>;
    _getRegState(regKey: PublicKey): Promise<RegistryState | undefined>;
    _getServerState(serverKey: PublicKey): Promise<ServerState | undefined>;
}
//# sourceMappingURL=solana-transport.d.ts.map